# Storey


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**uuid** | **str** | IFC element or element type UUID | [readonly] 
**name** | **str** | Name of the storey | [readonly] 
**plans** | [**[ModelWithPositioningPlan]**](ModelWithPositioningPlan.md) |  | [readonly] 
**plans_unreachable_count** | **int** |  | [readonly] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


